ux

package
v0.0.0-...-ab933d4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 24, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package ux consolidates UX models

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type UX

type UX struct {
	Ctx *ctx.Ctx

	Pacman     spinner.Model
	SideList   list.Model
	StreamList list.Model
}

func New

func New(ctx *ctx.Ctx) UX

Directories

Path Synopsis
items
stream
Package stream defines struct for a single Twitch stream for lists
Package stream defines struct for a single Twitch stream for lists
Package pacman provides a custom pacman spinner
Package pacman provides a custom pacman spinner
Package sidelist provides the item delegate for sidebar list
Package sidelist provides the item delegate for sidebar list
Package streamlist provides the item delegate for main stream list
Package streamlist provides the item delegate for main stream list

Jump to